pub struct VrtBuilder { /* private fields */ }Expand description
VRT builder for creating VRT datasets
Implementations
Sourceimpl VrtBuilder
impl VrtBuilder
Sourcepub fn with_size(width: u64, height: u64) -> Self
pub fn with_size(width: u64, height: u64) -> Self
Creates a VRT builder with specified dimensions
Sourcepub fn with_vrt_path<P: Into<PathBuf>>(self, path: P) -> Self
pub fn with_vrt_path<P: Into<PathBuf>>(self, path: P) -> Self
Sets the VRT file path (for resolving relative source paths)
Sourcepub fn with_geo_transform(self, geo_transform: GeoTransform) -> Self
pub fn with_geo_transform(self, geo_transform: GeoTransform) -> Self
Sets the GeoTransform
Sourcepub fn with_block_size(self, width: u32, height: u32) -> Self
pub fn with_block_size(self, width: u32, height: u32) -> Self
Sets the block size
Sourcepub fn add_source<P: AsRef<Path>>(
self,
path: P,
band_num: usize,
source_band: usize,
) -> Result<Self>
pub fn add_source<P: AsRef<Path>>( self, path: P, band_num: usize, source_band: usize, ) -> Result<Self>
Sourcepub fn add_source_with_window<P: AsRef<Path>>(
self,
path: P,
band_num: usize,
source_band: usize,
src_rect: PixelRect,
dst_rect: PixelRect,
) -> Result<Self>
pub fn add_source_with_window<P: AsRef<Path>>( self, path: P, band_num: usize, source_band: usize, src_rect: PixelRect, dst_rect: PixelRect, ) -> Result<Self>
Adds a source with a window to a band
Errors
Returns an error if the source configuration is invalid
Sourcepub fn add_tile<P: AsRef<Path>>(
self,
path: P,
x_off: u64,
y_off: u64,
width: u64,
height: u64,
) -> Result<Self>
pub fn add_tile<P: AsRef<Path>>( self, path: P, x_off: u64, y_off: u64, width: u64, height: u64, ) -> Result<Self>
Adds a mosaic tile at a specific position
Errors
Returns an error if the tile configuration is invalid
Sourcepub fn add_tile_grid<P>(
self,
paths: &[P],
tile_width: u64,
tile_height: u64,
cols: usize,
) -> Result<Self>
pub fn add_tile_grid<P>( self, paths: &[P], tile_width: u64, tile_height: u64, cols: usize, ) -> Result<Self>
Sourcepub fn set_dimensions(self, width: u64, height: u64) -> Self
pub fn set_dimensions(self, width: u64, height: u64) -> Self
Sets the dataset dimensions explicitly
Sourcepub fn build(self) -> Result<VrtDataset>
pub fn build(self) -> Result<VrtDataset>
Sourcepub fn build_file<P: AsRef<Path>>(self, path: P) -> Result<VrtDataset>
pub fn build_file<P: AsRef<Path>>(self, path: P) -> Result<VrtDataset>